@@ -15,6 +15,7 @@
 //
 // $URL$
 // $Id$
+// SPDX-License-Identifier: GPL-3.0+
 //
 //
 // Author(s)     : Laurent RINEAU, Stephane Tayeb
@@ -22,22 +23,28 @@
 #ifndef CGAL_IO_FILE_MEDIT_H
 #define CGAL_IO_FILE_MEDIT_H
 
+#include <CGAL/license/Mesh_3.h>
+
 #include <CGAL/Mesh_3/config.h>
 
+#include <CGAL/utility.h>
+#include <CGAL/basic.h>
+
+#include <boost/type_traits/is_same.hpp>
+#include <boost/unordered_map.hpp>
+#include <boost/utility/enable_if.hpp>
+
+#include <iomanip>
 #include <iostream>
 #include <map>
 #include <set>
-#include <vector>
 #include <string>
-#include <CGAL/utility.h>
-
-#include <boost/unordered_map.hpp>
+#include <vector>
 
 namespace CGAL {
 
 namespace Mesh_3 {
 
-
 //-------------------------------------------------------
 // Needed in verbose mode
 //-------------------------------------------------------
@@ -76,15 +83,14 @@ public:
          ++cell_it)
     {
       // Add subdomain index in internal map if needed
-      if ( subdomain_map_.end() ==
-              subdomain_map_.find(r_c3t3_.subdomain_index(cell_it)) )
-      {
-        subdomain_map_.insert(std::make_pair(r_c3t3_.subdomain_index(cell_it),
-                                             index_counter));
+      std::pair<typename Subdomain_map::iterator, bool> is_insert_successful =
+          subdomain_map_.insert(std::make_pair(r_c3t3_.subdomain_index(cell_it),
+                                               index_counter));
+
+      if(is_insert_successful.second)
         ++index_counter;
-      }
     }
-    
+
     // Rebind indices in alphanumeric order
     index_counter = first_index + 1;
     for ( typename Subdomain_map::iterator mit = subdomain_map_.begin() ;
@@ -179,11 +185,8 @@ public:
         cell_it != r_c3t3_.cells_in_complex_end();
         ++cell_it)
     {
-      // Add subdomain index in set if new
-      if ( subdomain_set.end() == subdomain_set.find(subdomain_index(cell_it)) )
-      {
-        subdomain_set.insert(subdomain_index(cell_it));
-      }
+      // Add subdomain index in set
+      subdomain_set.insert(subdomain_index(cell_it));
     }
     
     return subdomain_set.size();
@@ -229,14 +232,11 @@ public:
         ++facet_it)
     {
       // Add surface index in internal map if needed
-      if ( surface_map_.end() ==
-          surface_map_.find(c3t3.surface_patch_index((*facet_it).first,
-                                                     (*facet_it).second)) )
-      {
-        surface_map_.insert(std::make_pair(r_c3t3_.surface_patch_index(*facet_it),
-                                           index_counter));
+      std::pair<typename Surface_map::iterator, bool> is_insert_successful =
+          surface_map_.insert(std::make_pair(r_c3t3_.surface_patch_index(*facet_it),
+                                             index_counter));
+      if(is_insert_successful.second)
         ++index_counter;
-      }
     }
     
     // Find cell_pmap_ unused indices
@@ -247,12 +247,8 @@ public:
         cell_it != r_c3t3_.cells_in_complex_end();
         ++cell_it)
     {
-      // Add subdomain index in set if new
-      if ( cell_label_set.end()
-          == cell_label_set.find(get(cell_pmap_,cell_it)) )
-      {
-        cell_label_set.insert(get(cell_pmap_,cell_it));
-      }
+      // Add subdomain index in set
+      cell_label_set.insert(get(cell_pmap_, cell_it));
     }
     
     // Rebind indices
@@ -767,7 +763,7 @@ output_to_medit(std::ostream& os,
 
   typedef typename Tr::Finite_vertices_iterator Finite_vertices_iterator;
   typedef typename Tr::Vertex_handle Vertex_handle;
-  typedef typename Tr::Point Point_3;
+  typedef typename Tr::Weighted_point Weighted_point;
 
   const Tr& tr = c3t3.triangulation();
 
@@ -796,7 +792,7 @@ output_to_medit(std::ostream& os,
        ++vit)
   {
     V[vit] = inum++;
-    Point_3 p = vit->point();
+    Weighted_point p = tr.point(vit);
     os << CGAL::to_double(p.x()) << ' '
        << CGAL::to_double(p.y()) << ' '
        << CGAL::to_double(p.z()) << ' '
@@ -869,9 +865,6 @@ output_to_medit(std::ostream& os,
 
 } // end namespace Mesh_3
 
-  
-
-  
 /**
  * @brief outputs mesh to medit format
  * @param os the stream
@@ -886,7 +879,7 @@ void
 output_to_medit(std::ostream& os,
                 const C3T3& c3t3,
                 bool rebind = false,
-                bool show_patches = false) 
+                bool show_patches = false)
 {
   if ( rebind )
   {
