@@ -69,7 +69,7 @@ struct Construct_algebraic_real_z_1{
 
 template <class Polynomial_,class Algebraic_>
 struct Compute_polynomial_z_1:
-public CGAL::unary_function<Algebraic_,Polynomial_>{
+public CGAL::cpp98::unary_function<Algebraic_,Polynomial_>{
         typedef Polynomial_                                     Polynomial;
         typedef Algebraic_                                      Algebraic;
         Polynomial operator()(const Algebraic &x)const{
@@ -79,7 +79,7 @@ public CGAL::unary_function<Algebraic_,Polynomial_>{
 
 template <class Polynomial_,class Ptraits_>
 struct Is_coprime_z_1:
-public CGAL::binary_function<Polynomial_,Polynomial_,bool>{
+public CGAL::cpp98::binary_function<Polynomial_,Polynomial_,bool>{
         typedef Polynomial_                                     Polynomial;
         typedef Ptraits_                                        Ptraits;
         typedef typename Ptraits::Gcd_up_to_constant_factor     Gcd;
@@ -285,7 +285,7 @@ template <class Polynomial_,
           class Ptraits_,
           class ZPtraits_>
 class Sign_at_z_1:
-public CGAL::binary_function<Polynomial_,Algebraic_,CGAL::Sign>{
+public CGAL::cpp98::binary_function<Polynomial_,Algebraic_,CGAL::Sign>{
         // This implementation will work with any polynomial type whose
         // coefficient type is explicit interoperable with Gmpfi.
         // TODO: Make this function generic.
@@ -397,7 +397,7 @@ template <class Polynomial_,
           class Ptraits_,
           class ZPtraits_>
 class Is_zero_at_z_1:
-public CGAL::binary_function<Polynomial_,Algebraic_,bool>{
+public CGAL::cpp98::binary_function<Polynomial_,Algebraic_,bool>{
         // This implementation will work with any polynomial type whose
         // coefficient type is explicit interoperable with Gmpfi.
         // TODO: Make this function generic.
@@ -483,7 +483,7 @@ template <class Polynomial_,
           class PolConverter_,
           class Isolator_>
 struct Number_of_solutions_z_1:
-public CGAL::unary_function<Polynomial_,int>{
+public CGAL::cpp98::unary_function<Polynomial_,int>{
         typedef Polynomial_                                     Polynomial_1;
         typedef ZPolynomial_                                    ZPolynomial_1;
         typedef PolConverter_                                   PolConverter;
@@ -501,7 +501,7 @@ template <class Algebraic_,
           class Bound_,
           class Comparator_>
 struct Compare_z_1:
-public CGAL::binary_function<Algebraic_,Algebraic_,CGAL::Comparison_result>{
+public CGAL::cpp98::binary_function<Algebraic_,Algebraic_,CGAL::Comparison_result>{
         typedef Algebraic_                                      Algebraic;
         typedef Bound_                                          Bound;
         typedef Comparator_                                     Comparator;
@@ -553,7 +553,7 @@ template <class Algebraic_,
           class Bound_,
           class Comparator_>
 struct Bound_between_z_1:
-public CGAL::binary_function<Algebraic_,Algebraic_,Bound_>{
+public CGAL::cpp98::binary_function<Algebraic_,Algebraic_,Bound_>{
         typedef Algebraic_                                      Algebraic;
         typedef Bound_                                          Bound;
         typedef Comparator_                                     Comparator;
@@ -596,7 +596,7 @@ template <class Polynomial_,
           class Ptraits_,
           class ZPtraits_>
 struct Isolate_z_1:
-public CGAL::binary_function<Algebraic_,Polynomial_,std::pair<Bound_,Bound_> >{
+public CGAL::cpp98::binary_function<Algebraic_,Polynomial_,std::pair<Bound_,Bound_> >{
         typedef Polynomial_                                     Polynomial_1;
         typedef ZPolynomial_                                    ZPolynomial_1;
         typedef PolConverter_                                   PolConverter;
@@ -640,7 +640,7 @@ template <class Polynomial_,
           class Algebraic_,
           class Refiner_>
 struct Approximate_absolute_z_1:
-public CGAL::binary_function<Algebraic_,int,std::pair<Bound_,Bound_> >{
+public CGAL::cpp98::binary_function<Algebraic_,int,std::pair<Bound_,Bound_> >{
         typedef Polynomial_                                     Polynomial_1;
         typedef Bound_                                          Bound;
         typedef Algebraic_                                      Algebraic;
@@ -672,7 +672,7 @@ template <class Polynomial_,
           class Algebraic_,
           class Refiner_>
 struct Approximate_relative_z_1:
-public CGAL::binary_function<Algebraic_,int,std::pair<Bound_,Bound_> >{
+public CGAL::cpp98::binary_function<Algebraic_,int,std::pair<Bound_,Bound_> >{
         typedef Polynomial_                                     Polynomial_1;
         typedef Bound_                                          Bound;
         typedef Algebraic_                                      Algebraic;
